@@ -3,11 +3,11 @@
 var ToLength = require('es-abstract/2020/ToLength');
 var ToString = require('es-abstract/2020/ToString');
 var RequireObjectCoercible = require('es-abstract/2020/RequireObjectCoercible');
-var callBound = require('call-bind/callBound');
 
+var callBound = require('call-bind/callBound');
 var $slice = callBound('String.prototype.slice');
 
-module.exports = function padEnd(maxLength) {
+module.exports = function padStart(maxLength) {
 	var O = RequireObjectCoercible(this);
 	var S = ToString(O);
 	var stringLength = ToLength(S.length);
@@ -31,5 +31,5 @@ module.exports = function padEnd(maxLength) {
 	}
 
 	var truncatedStringFiller = filler.length > fillLen ? $slice(filler, 0, fillLen) : filler;
-	return S + truncatedStringFiller;
+	return truncatedStringFiller + S;
 };
